@@ -1,10 +1,11 @@
 from mongoengine import *
 from securemongoengine.fields import *
+import random
 
 _key = 'workingWithAES256AlgorithmKey32B'
 
 class User(Document):
-    name = EncryptedStringField(key=_key,max_length=40, required=True)
+    name = EncryptedStringField(key=_key,max_length=40, required=True,mode='EBC',iv=''.join(chr(random.randint(0, 0xFF)) for i in range(16)))
     lastname = EncryptedStringField(key=_key,max_length=40, required=True)
     email = EncryptedEmailField(algorithm='AES',key=_key,required=True, unique=True)
     password = EncryptedStringField(key=_key,max_length=40, required=True)
